summaryrefslogtreecommitdiffstats
path: root/kdejava/koala/examples/kscribble/KScribbleApp.java
diff options
context:
space:
mode:
Diffstat (limited to 'kdejava/koala/examples/kscribble/KScribbleApp.java')
-rw-r--r--kdejava/koala/examples/kscribble/KScribbleApp.java42
1 files changed, 21 insertions, 21 deletions
diff --git a/kdejava/koala/examples/kscribble/KScribbleApp.java b/kdejava/koala/examples/kscribble/KScribbleApp.java
index b2009802..f0ea02ad 100644
--- a/kdejava/koala/examples/kscribble/KScribbleApp.java
+++ b/kdejava/koala/examples/kscribble/KScribbleApp.java
@@ -9,17 +9,17 @@ import org.kde.koala.*;
* Child windows are created in createClient(), which gets a document instance as it's document to
* display whereby one document can have several views.The MDI child is an instance of KScribbleView,
* the document an instance of KScribbleDoc.
* KScribbleApp reimplements the methods that KMainWindow provides for main window handling and supports
* full session management as well as keyboard accelerator configuration by using KAccel.
* @see KMainWindow
* @see TDEApplication
* @see TDEConfig
- * @see KAccel
+ * @see TDEAccel
*
* @author Source Framework Automatically Generated by KDevelop, (c) The KDevelop Team.
* @version KDevelop version 1.1 code generation
*/
-public class KScribbleApp extends KMainWindow implements Resource {
+public class KScribbleApp extends TDEMainWindow implements Resource {
/** the configuration object of the application */
private TDEConfig config;
@@ -84,26 +84,26 @@ public class KScribbleApp extends KMainWindow implements Resource {
this(null, null);
}
- /** initializes the KActions of the application */
+ /** initializes the TDEActions of the application */
protected void initKeyAccel() {
- KAccel keyAccel = new KAccel(this);
+ TDEAccel keyAccel = new TDEAccel(this);
// fileMenu accelerators
- keyAccel.insert(KStdAccel.New, this, SLOT("slotFileNew()"));
- keyAccel.insert(KStdAccel.Open, this, SLOT("slotFileOpen()"));
- keyAccel.insert(KStdAccel.Save, this, SLOT("slotFileSave()"));
- keyAccel.insert(KStdAccel.Close, this, SLOT("slotFileClose()"));
- keyAccel.insert(KStdAccel.Print, this, SLOT("slotFilePrint()"));
- keyAccel.insert(KStdAccel.Quit, this, SLOT("slotFileQuit()"));
+ keyAccel.insert(TDEStdAccel.New, this, SLOT("slotFileNew()"));
+ keyAccel.insert(TDEStdAccel.Open, this, SLOT("slotFileOpen()"));
+ keyAccel.insert(TDEStdAccel.Save, this, SLOT("slotFileSave()"));
+ keyAccel.insert(TDEStdAccel.Close, this, SLOT("slotFileClose()"));
+ keyAccel.insert(TDEStdAccel.Print, this, SLOT("slotFilePrint()"));
+ keyAccel.insert(TDEStdAccel.Quit, this, SLOT("slotFileQuit()"));
// editMenu accelerators
- keyAccel.insert(KStdAccel.Cut, this, SLOT("slotEditCut()"));
- keyAccel.insert(KStdAccel.Copy, this, SLOT("slotEditCopy()"));
- keyAccel.insert(KStdAccel.Paste, this, SLOT("slotEditPaste()"));
+ keyAccel.insert(TDEStdAccel.Cut, this, SLOT("slotEditCut()"));
+ keyAccel.insert(TDEStdAccel.Copy, this, SLOT("slotEditCopy()"));
+ keyAccel.insert(TDEStdAccel.Paste, this, SLOT("slotEditPaste()"));
// help accelerator
- keyAccel.insert(KStdAccel.Help, this, SLOT("appHelpActivated()"));
+ keyAccel.insert(TDEStdAccel.Help, this, SLOT("appHelpActivated()"));
keyAccel.readSettings();
@@ -611,8 +611,8 @@ public class KScribbleApp extends KMainWindow implements Resource {
}
// bar position settings
- int toolBarPos = KToolBar.Top;
- toolBarPos = config.readUnsignedNumEntry("ToolBarPos", KToolBar.Top);
+ int toolBarPos = TDEToolBar.Top;
+ toolBarPos = config.readUnsignedNumEntry("ToolBarPos", TDEToolBar.Top);
toolBar().setBarPos(toolBarPos);
// initialize the recent file list
@@ -819,13 +819,13 @@ public class KScribbleApp extends KMainWindow implements Resource {
saveOptions();
// close the first window, the list makes the next one the first again.
// This ensures that queryClose() is called on each window to ask for closing
- KMainWindow w;
+ TDEMainWindow w;
ArrayList memberlist = memberList();
if(memberlist != null) {
Iterator it = memberlist.iterator();
while (it.hasNext()) {
- w = (KMainWindow)it.next();
+ w = (TDEMainWindow)it.next();
// only close the window if the closeEvent is accepted. If the user
// presses Cancel on the saveModified() dialog,
// the window and the application stay open.
@@ -9,17 +9,17 @@ import org.kde.koala.*;
* display whereby one document can have several views.The MDI child is an instance of KScribbleView,
* the document an instance of KScribbleDoc.
- * KScribbleApp reimplements the methods that KMainWindow provides for main window handling and supports
- * full session management as well as keyboard accelerator configuration by using KAccel.
- * @see KMainWindow
+ * KScribbleApp reimplements the methods that TDEMainWindow provides for main window handling and supports
+ * full session management as well as keyboard accelerator configuration by using TDEAccel.
+ * @see TDEMainWindow
* @see TDEApplication
* @see TDEConfig